summaryrefslogtreecommitdiff
path: root/NxWidgets/nxwm/include/cnxconsole.hxx
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-04-30 01:21:26 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-04-30 01:21:26 +0000
commit284cd6923b521898c0927992fab77593ad797b4a (patch)
treeecdc27cff477efee7da31d0fae65b527377e094f /NxWidgets/nxwm/include/cnxconsole.hxx
parent45f021f2a88d9f76c7802aa31d3fc67827ff288d (diff)
downloadnuttx-284cd6923b521898c0927992fab77593ad797b4a.tar.gz
nuttx-284cd6923b521898c0927992fab77593ad797b4a.tar.bz2
nuttx-284cd6923b521898c0927992fab77593ad797b4a.zip
NxWM update
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4677 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'NxWidgets/nxwm/include/cnxconsole.hxx')
-rw-r--r--NxWidgets/nxwm/include/cnxconsole.hxx12
1 files changed, 5 insertions, 7 deletions
diff --git a/NxWidgets/nxwm/include/cnxconsole.hxx b/NxWidgets/nxwm/include/cnxconsole.hxx
index 891ac8884..4009eb8b9 100644
--- a/NxWidgets/nxwm/include/cnxconsole.hxx
+++ b/NxWidgets/nxwm/include/cnxconsole.hxx
@@ -42,9 +42,7 @@
#include <nuttx/config.h>
-#include "crlepalettebitmap.hxx"
-#include "inxwindow.hxx"
-#include "cnxapplication.hxx"
+#include "iapplication.hxx"
/****************************************************************************
* Pre-Processor Definitions
@@ -62,7 +60,7 @@ namespace NxWM
* This class implements the NxConsole application.
*/
- class CNxConsole : public CNxApplication
+ class CNxConsole : public IApplication
{
protected:
/**
@@ -83,12 +81,12 @@ namespace NxWM
/**
* Get the icon associated with the application
*
* @return An instance if INxBitmap that may be used to rend the
* application's icon. This is an new INxBitmap instance that must
* be deleted by the caller when it is no long needed.
*/
- NXWidgets::INxBitmap *getIcon(void);
+ NXWidgets::IBitmap *getIcon(void);
};
}
#endif // __cplusplus
@@ -83,12 +81,12 @@ namespace NxWM
* Get the icon associated with the application
*
- * @return An instance if INxBitmap that may be used to rend the
- * application's icon. This is an new INxBitmap instance that must
+ * @return An instance if IBitmap that may be used to rend the
+ * application's icon. This is an new IBitmap instance that must
* be deleted by the caller when it is no long needed.
*/